@@ -1,3 +1,6 @@
+from splatnet3_scraper.auth.environment_manager import (
+    EnvironmentVariablesManager,
+)
 from splatnet3_scraper.auth.graph_ql_queries import GraphQLQueries
 from splatnet3_scraper.auth.nso import NSO
 from splatnet3_scraper.auth.token_manager import Token, TokenManager
